@@ -26,8 +26,7 @@ Command::Command()
 
 bool Command::operator==(const Command& other) const
 {
-    return name == other.name && script == other.script
-        && help == other.help && description == other.description;
+    return name == other.name;
 }
 
 bool Command::operator!=(const Command& other) const
