@@ -23,6 +23,7 @@
 
 #include <QMap>
 #include <QString>
+#include <QStringList>
 
 struct Command
 {
@@ -34,6 +35,7 @@ struct Command
     QString script;
     QString help;
     QString description;
+    QStringList categories;
 };
 typedef QMap<QString, Command> Commands;
 
