@@ -30,14 +30,17 @@ class Session : public Irc::Session
 
 public:
     Session(QObject* parent = 0);
+    ~Session();
 
     Connection connection() const;
 
+    static bool isChannel(const QString& receiver);
+
 public slots:
     void connectTo(const Connection& connection);
 
 private:
-    Connection conn;
+    mutable Connection conn;
 };
 
 #endif // SESSION_H
