@@ -37,12 +37,15 @@ public:
 
 signals:
     void send(const QString& text);
+    void help(const QString& command = QString());
 
 protected:
     void hideEvent(QHideEvent* event);
 
 private slots:
     void onSend();
+    void updateUi();
+    void commandAction(QAction* action);
 
 private:
     struct EditFrameUi : public Ui::EditFrame
