@@ -19,29 +19,28 @@
 */
 
 #include "connectionwizardpage.h"
+#include <QCompleter>
+#include <QSettings>
 
 ConnectionWizardPage::ConnectionWizardPage(QWidget* parent) : QWizardPage(parent)
 {
     ui.setupUi(this);
     setPixmap(QWizard::LogoPixmap, QPixmap(":/resources/oxygen/64x64/actions/save_all.png"));
+
+    QSettings settings;
+    QStringList names = settings.value("connectionNames").toStringList();
+
+    QCompleter* completer = new QCompleter(names, ui.lineEditName);
+    completer->setCaseSensitivity(Qt::CaseInsensitive);
+    ui.lineEditName->setCompleter(completer);
 }
 
 QString ConnectionWizardPage::connectionName() const
 {
-    return ui.comboBoxName->currentText();
+    return ui.lineEditName->text();
 }
 
 void ConnectionWizardPage::setConnectionName(const QString& name)
 {
-    ui.comboBoxName->setEditText(name);
-}
-
-bool ConnectionWizardPage::autoConnect() const
-{
-    return ui.checkBoxConnect->isChecked();
-}
-
-void ConnectionWizardPage::setAutoConnect(bool enabled)
-{
-    ui.checkBoxConnect->setChecked(enabled);
+    ui.lineEditName->setText(name);
 }
